@@ -55,7 +55,6 @@ class FeatureGenerator:
         for key in [
             "from_obj",
             "intervals",
-            "groups",
             "knowledge_date_column",
             "prefix",
         ]:
@@ -65,6 +64,17 @@ class FeatureGenerator:
                         key, aggregation_config
                     )
                 )
+        if "groups" in aggregation_config:
+            if aggregation_config["groups"] != [self.entity_id_column]:
+                raise ValueError(
+                    "Specifying groupings for feature aggregation is not supported. "
+                    "Features can only be grouped at the {} level.".format(self.entity_id_column)
+                    )
+            else:
+                logger.warning(
+                    "Specifying groupings for feature aggregation is not supported. "
+                    "In the future, please exclude this key from your feature configuration."
+                    )
 
     def _validate_aggregates(self, aggregation_config):
         if (
@@ -108,13 +118,6 @@ class FeatureGenerator:
             if interval != "all":
                 convert_str_to_relativedelta(interval)
 
-    def _validate_groups(self, groups):
-        logger.spam("Validating groups")
-        if "entity_id" not in groups:
-            raise ValueError(
-                "One of the aggregation groups is required to be entity_id"
-            )
-
     def _validate_imputation_rule(self, aggregate_type, impute_rule):
         """Validate the imputation rule for a given aggregation type."""
         logger.spam("Validating imputation rule")
@@ -189,7 +192,6 @@ class FeatureGenerator:
         self._validate_categoricals(aggregation_config.get("categoricals", []))
         self._validate_from_obj(aggregation_config["from_obj"])
         self._validate_time_intervals(aggregation_config["intervals"])
-        self._validate_groups(aggregation_config["groups"])
         self._validate_imputations(aggregation_config)
 
     def validate(self, feature_aggregation_config):
@@ -307,7 +309,7 @@ class FeatureGenerator:
             aggregates + categoricals + array_categoricals,
             from_obj=aggregation_config["from_obj"],
             intervals=aggregation_config["intervals"],
-            groups=aggregation_config["groups"],
+            groups=[self.entity_id_column],
             dates=feature_dates,
             state_table=state_table,
             state_group=self.entity_id_column,
@@ -606,7 +608,7 @@ class FeatureGenerator:
 
         return table_tasks
 
-    def _generate_imp_table_tasks_for(self, aggregation, drop_preagg=True):
+    def _generate_imp_table_tasks_for(self, aggregation, impute_cols=None, nonimpute_cols=None, drop_preagg=True):
         """Generate SQL statements for preparing, populating, and
         finalizing imputations, for each feature group table in the
         given aggregation.
@@ -653,8 +655,10 @@ class FeatureGenerator:
         with self.db_engine.begin() as conn:
             results = conn.execute(aggregation.find_nulls())
             null_counts = results.first().items()
-        impute_cols = [col for (col, val) in null_counts if val > 0]
-        nonimpute_cols = [col for (col, val) in null_counts if val == 0]
+        if impute_cols is None:
+            impute_cols = [col for (col, val) in null_counts if val > 0]
+        if nonimpute_cols is None:
+            nonimpute_cols = [col for (col, val) in null_counts if val == 0]
 
         # table tasks for imputed aggregation table, most of the work is done here
         # by collate's get_impute_create()
