@@ -1,12 +1,36 @@
-import logging
+import verboselogs, logging
+logger = verboselogs.VerboseLogger(__name__)
 
-import pandas
 from sqlalchemy.orm import sessionmaker
 
 from triage.component.architect.entity_date_table_generators import EntityDateTableGenerator
 from triage.component.catwalk.utils import (filename_friendly_hash, get_subset_table_name)
 from triage.component.results_schema import Subset
 
+
+class SubsetterNoOp:
+    def generate_tasks(self, subset_configs):
+        logger.debug(
+            "No subsets configuration is available, so subsets tasks will not be created"
+        )
+
+        return []
+
+    def process_all_tasks(self, tasks):
+        logger.notice(
+            "No subsets configuration is available, so subsets will not be created"
+        )
+
+    def process_task(self, subset_config, subset_hash, subset_table_generator):
+        logger.notice(
+            "No subsets configuration is available, so subset task  will not be created"
+        )
+
+    def save_subset_to_db(self, subset_hash, subset_config):
+        logger.notice(
+            "No subsets configuration is available, so subsets will not be created"
+        )
+
 class Subsetter:
     def __init__(
         self,
@@ -19,7 +43,7 @@ class Subsetter:
         self.as_of_times = as_of_times
 
     def generate_tasks(self, subset_configs):
-        logging.info("Generating subset table creation tasks")
+        logger.debug("Generating subset table creation tasks")
         subset_tasks = []
         for subset_config in subset_configs:
             if subset_config:
@@ -40,19 +64,20 @@ class Subsetter:
         return subset_tasks
 
     def process_all_tasks(self, tasks):
+        logger.info("Creating subsets")
         for task in tasks:
             self.process_task(**task)
+        logger.success("Subsets stored successfully")
 
     def process_task(self, subset_config, subset_hash, subset_table_generator):
-        logging.info(
-            "Beginning subset creation for %s-%s",
-            subset_config["name"],
-            subset_hash
+        logger.debug(
+            f"Creating subset for {subset_config['name']}-{subset_hash}"
         )
         subset_table_generator.generate_entity_date_table(
             as_of_dates=self.as_of_times
         )
         self.save_subset_to_db(subset_hash, subset_config)
+        logger.debug(f"Subset {subset_config['name']}-{subset_hash} created successfully")
 
     def save_subset_to_db(self, subset_hash, subset_config):
         session = sessionmaker(bind=self.db_engine)()
