@@ -13,14 +13,16 @@ from triage.database_reflection import table_exists
 from .schema import (
     Base,
     Experiment,
+    Retrain,
     FeatureImportance,
     IndividualImportance,
     ListPrediction,
     ExperimentMatrix,
     Matrix,
     ExperimentModel,
-    ExperimentRun,
-    ExperimentRunStatus,
+    RetrainModel,
+    TriageRun,
+    TriageRunStatus,
     Model,
     ModelGroup,
     Subset,
@@ -30,6 +32,7 @@ from .schema import (
     TrainPrediction,
     TestPredictionMetadata,
     TrainPredictionMetadata,
+    ListPredictionMetadata,
     TrainAequitas,
     TestAequitas
 )
@@ -38,14 +41,16 @@ from .schema import (
 __all__ = (
     "Base",
     "Experiment",
+    "Retrain",
     "FeatureImportance",
     "IndividualImportance",
     "ListPrediction",
     "ExperimentMatrix",
     "Matrix",
+    "RetrainModel",
     "ExperimentModel",
-    "ExperimentRun",
-    "ExperimentRunStatus",
+    "TriageRun",
+    "TriageRunStatus",
     "Model",
     "ModelGroup",
     "Subset",
@@ -55,6 +60,7 @@ __all__ = (
     "TrainPrediction",
     "TestPredictionMetadata",
     "TrainPredictionMetadata",
+    "ListPredictionMetadata",
     "TestAequitas",
     "TrainAequitas",
     "mark_db_as_upgraded",
