@@ -1,13 +1,15 @@
 import verboselogs, logging
+
 logger = verboselogs.VerboseLogger(__name__)
 
+import copy
+import os
 import re
 
 from dateutil.relativedelta import relativedelta
 from datetime import datetime
 
 
-
 def parse_from_obj(config, alias):
     """
     Parses a from_obj configuration key. If it's a from_obj_table just returns it.
@@ -25,6 +27,7 @@ def parse_from_obj(config, alias):
         return " ({}) {} ".format(from_obj, alias) if from_obj else None
     return from_obj
 
+
 def dt_from_str(dt_str):
     if isinstance(dt_str, datetime):
         return dt_str
@@ -64,6 +67,32 @@ def parse_delta_string(delta_string):
 parse_delta_string.pattern = re.compile(r"^(\d+) *([^ ]+)$")
 
 
+def load_query_if_needed(config_component):
+    """Load the cohort or label query from a file
+
+    Args:
+        config_component (dict) A cohort or label config
+
+    Returns: None
+    """
+    config_component_copy = copy.copy(config_component)
+    if "filepath" in config_component_copy:
+        logger.warn(
+            "Loading query from file; if there is a query in the config, it will be overwritten"
+        )
+
+        query_filename = os.path.join(
+            os.path.abspath(os.getcwd()), config_component_copy["filepath"]
+        )
+
+        with open(query_filename) as f:
+            config_component_copy["query"] = f.read()
+
+        config_component_copy.pop("filepath")
+
+    return config_component_copy
+
+
 def convert_str_to_relativedelta(delta_string):
     """Given a string in a postgres interval format (e.g., '1 month'),
     convert it to a dateutil.relativedelta.relativedelta.
@@ -97,9 +126,7 @@ def convert_str_to_relativedelta(delta_string):
         pass
     else:
         if unit_type == "minutes":
-            logger.warning(
-                f'Time delta units "{units}" converted to minutes.'
-            )
+            logger.warning(f'Time delta units "{units}" converted to minutes.')
         return relativedelta(**{unit_type: value})
 
     raise ValueError("Could not handle units. Units: {} Value: {}".format(units, value))
